MaybeParsedNetlinkMessage

Trait MaybeParsedNetlinkMessage 

pub trait MaybeParsedNetlinkMessage {
    type Message: MessageWithPermission;

    // Required method
    fn try_into_parsed(
        self,
    ) -> Result<NetlinkMessage<Self::Message>, ParseError>;
}
A trait abstracting netlink messages that may already be parsed or still need to go through parsing.

Required Associated Types

type Message: MessageWithPermission

The inner message type potentially contained by this message.

Required Methods

fn try_into_parsed(self) -> Result<NetlinkMessage<Self::Message>, ParseError>

Parses the message, returning an owned NetlinkMessage on success.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<M: MessageWithPermission> MaybeParsedNetlinkMessage for NetlinkMessage<M>

Implementors