pub trait NetlinkContext {
type Creds: Clone + Send + Debug;
type Sender<M: Clone + NetlinkSerializable + Send>: Sender<M>;
type Receiver<M: Send + MessageWithPermission + NetlinkDeserializable<Error: Into<DecodeError>>>: Receiver<M, Self::Creds>;
type AccessControl<'a>: AccessControl<Self::Creds>;
}Expand description
A type capable of providing a concrete types used in Netlink.
Required Associated Types
Sourcetype Receiver<M: Send + MessageWithPermission + NetlinkDeserializable<Error: Into<DecodeError>>>: Receiver<M, Self::Creds>
type Receiver<M: Send + MessageWithPermission + NetlinkDeserializable<Error: Into<DecodeError>>>: Receiver<M, Self::Creds>
The type of Receiver provided.
Sourcetype AccessControl<'a>: AccessControl<Self::Creds>
type AccessControl<'a>: AccessControl<Self::Creds>
The type of an object that validates access to netlink operations.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".